Index: tmp/org.txm.core/src/java/org/txm/objects/Project.java
===================================================================
--- tmp/org.txm.core/src/java/org/txm/objects/Project.java	(revision 1151)
+++ tmp/org.txm.core/src/java/org/txm/objects/Project.java	(revision 1152)
@@ -316,9 +316,6 @@
 		}
 	}
 
-
-
-
 	//	public BasePreferenceScope getPreferenceScope() {
 	//		return scope;
 	//	}
Index: tmp/org.txm.core/src/java/org/txm/Toolbox.java
===================================================================
--- tmp/org.txm.core/src/java/org/txm/Toolbox.java	(revision 1151)
+++ tmp/org.txm.core/src/java/org/txm/Toolbox.java	(revision 1152)
@@ -319,7 +319,6 @@
 				try {
 
 					Log.finest("Toolbox.initialize(): checking result type linked to node path " + parametersNodePath);
-
 					
 					String className = TXMPreferences.preferencesRootNode.node(parametersNodePath).get("class", ""); //$NON-NLS-1$
 					
@@ -327,14 +326,11 @@
 					//	Log.finest("Toolbox.initialize(): not a project, result skipped (classame = " + className + ").");
 						continue;
 					}
-
 					
 					Log.finest("Toolbox.initialize(): loading from result node path " + parametersNodePath);
 					//Log.finest("Toolbox.initialize(): class = " + TXMPreferences.getString("class", nodeQualifier));
 					//TXMPreferences.dump();
 					
-
-					
 					Log.finest("Toolbox.initialize(): class = " + className); //$NON-NLS-1$
 					Log.finest("Toolbox.initialize(): parent_uuid = " + TXMPreferences.preferencesRootNode.node(parametersNodePath).get(TXMPreferences.PARENT_UUID, "")); //$NON-NLS-1$
 					String bundleId = TXMPreferences.preferencesRootNode.node(parametersNodePath).get(TXMPreferences.BUNDLE_ID, ""); //$NON-NLS-1$
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/views/corpora/CorporaView.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/views/corpora/CorporaView.java	(revision 1151)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/views/corpora/CorporaView.java	(revision 1152)
@@ -412,27 +412,27 @@
 //		 	      }
 //		 	   }
 //		 	});
-		 	treeViewer.getTree().addListener(SWT.PaintItem, new Listener() {
-		 	   public void handleEvent(Event event) {
-		 		   if(event.item.getData() instanceof TXMResult && ((TXMResult)event.item.getData()).isUserPersistable())	{
-			 	      TreeItem item = (TreeItem)event.item;
-			 	      Image trailingImage = (Image)item.getImage();
-			 	      if (trailingImage != null) {
-			 	         //int x = event.x + event.width + IMAGE_MARGIN;
-			 	        int x = event.x + event.width;
-			 	        //int x = event.x - 20;
-			 	       //int x = event.x - 5;
-			 	         int itemHeight = treeViewer.getTree().getItemHeight();
-			 	         int imageHeight = trailingImage.getBounds().height;
-			 	         int y = event.y + (itemHeight - imageHeight) / 2;
-			 	        //int y = event.y + 5;
-			 	        
-			 	       event.gc.drawImage(icon, x, y); 
-			 	        //event.gc.drawImage(PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_ETOOL_SAVE_EDIT_DISABLED), x, y);
-			 	      }
-		 		   }
-		 	   }
-		 	});
+//		 	treeViewer.getTree().addListener(SWT.PaintItem, new Listener() {
+//		 	   public void handleEvent(Event event) {
+//		 		   if(event.item.getData() instanceof TXMResult && ((TXMResult)event.item.getData()).isUserPersistable())	{
+//			 	      TreeItem item = (TreeItem)event.item;
+//			 	      Image trailingImage = (Image)item.getImage();
+//			 	      if (trailingImage != null) {
+//			 	         //int x = event.x + event.width + IMAGE_MARGIN;
+//			 	        int x = event.x + event.width;
+//			 	        //int x = event.x - 20;
+//			 	       //int x = event.x - 5;
+//			 	         int itemHeight = treeViewer.getTree().getItemHeight();
+//			 	         int imageHeight = trailingImage.getBounds().height;
+//			 	         int y = event.y + (itemHeight - imageHeight) / 2;
+//			 	        //int y = event.y + 5;
+//			 	        
+//			 	       event.gc.drawImage(icon, x, y); 
+//			 	        //event.gc.drawImage(PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_ETOOL_SAVE_EDIT_DISABLED), x, y);
+//			 	      }
+//		 		   }
+//		 	   }
+//		 	});
 		
 		
 		MenuManager menuManager = new MenuManager();
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/adapters/TXMResultAdapter.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/adapters/TXMResultAdapter.java	(revision 1151)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/adapters/TXMResultAdapter.java	(revision 1152)
@@ -37,7 +37,8 @@
 	@Override
 	public String getLabel(Object result) {
 		if (result instanceof TXMResult) {
-			return ((TXMResult) result).getCurrentName();
+			String star = ((TXMResult) result).isUserPersistable()?"":" *";
+			return ((TXMResult) result).getCurrentName()+star;
 		}
 		else {
 			return result.toString();
@@ -62,11 +63,11 @@
 
 	@Override
     public RGB getForeground(Object element) {
-		if(element instanceof TXMResult && !((TXMResult)element).hasBeenComputedOnce())	{
-	    	Display display = Display.getCurrent();
-	    	Color color = display.getSystemColor(SWT.COLOR_DARK_GRAY);
-	    	return color.getRGB();
-		}
+//		if(element instanceof TXMResult && !((TXMResult)element).hasBeenComputedOnce())	{
+//	    	Display display = Display.getCurrent();
+//	    	Color color = display.getSystemColor(SWT.COLOR_DARK_GRAY);
+//	    	return color.getRGB();
+//		}
 		// FIXME: DEbug
 //		else if(element instanceof TXMResult && ((TXMResult)element).isDirty())	{
 //	    	Display display = Display.getCurrent();
Index: tmp/org.txm.searchengine.cqp.core/src/org/txm/searchengine/cqp/corpus/Part.java
===================================================================
--- tmp/org.txm.searchengine.cqp.core/src/org/txm/searchengine/cqp/corpus/Part.java	(revision 1151)
+++ tmp/org.txm.searchengine.cqp.core/src/org/txm/searchengine/cqp/corpus/Part.java	(revision 1152)
@@ -59,7 +59,6 @@
 		this.pName = partName;
 		this.setVisible(false);
 		this.internalPersistable = true;
-		this.userPersistable = false;
 	}
 	
 	/**
@@ -71,7 +70,6 @@
 		
 		this.setVisible(false);
 		this.internalPersistable = true;
-		this.userPersistable = false;
 	}
 	
 	@Override

Index: tmp/org.txm.core/src/java/org/txm/core/results/TXMResult.java
===================================================================
--- tmp/org.txm.core/src/java/org/txm/core/results/TXMResult.java	(revision 1151)
+++ tmp/org.txm.core/src/java/org/txm/core/results/TXMResult.java	(revision 1152)
@@ -1869,8 +1869,8 @@
 				this.children.get(i).setDirty();
 			}
 			
-			// Children cascade computing
-			if (deepComputing) {
+			// Children cascade computing ; if parent == null this is the Workspace
+			if (deepComputing && parent != null) {
 
 				Log.finest("TXMResult.compute(): " + this.getClass().getSimpleName() + ": cascade computing of " + this.children.size() + " children.");
 